==> nextcloud-13.0.1.tgz: nextcloud/apps/files_external/l10n/is.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Utanáliggjandi gagnageymslur",
    "Personal" : "Einka",
    "System" : "Kerfi",
    "Grant access" : "Veita aðgengi",
    "Error configuring OAuth1" : "Villa við uppsetningu OAuth1",
    "Please provide a valid app key and secret." : "Settu inn gildan forritslykil og leynilykil (secret).",
    "Error configuring OAuth2" : "Villa við uppsetningu OAuth2",
    "Generate keys" : "Útbúa lykla",
    "Error generating key pair" : "Villa við að útbúa nýtt lyklapar",
    "All users. Type to select user or group." : "Allir notendur. Skrifaðu til að velja notanda eða hóp.",
    "(group)" : "(hópur)",
    "Compatibility with Mac NFD encoding (slow)" : "Samhæfni við Mac NFD kóðun (hægvirkt)",
    "Admin defined" : "Skilgreindur kerfisstjóri",
    "Delete storage?" : "Eyða geymslu?",
    "Saved" : "Vistað",
    "Saving..." : "Er að vista ...",
    "Save" : "Vista",
    "Empty response from the server" : "Tómt svar frá þjóni móttekið",
    "Couldn't access. Please log out and in again to activate this mount point" : "Náði ekki aðgangi. Skráðu þig út og svo aftur inn til að virkja þennan tengipunkt",
    "Couldn't get the information from the remote server: {code} {type}" : "Gat ekki lesið upplýsingar frá fjartengda þjóninum: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Gat ekki fengið lista yfir fjartengda tengipunkta: {type}",
    "There was an error with message: " : "Það kom upp villa með skilaboðunum: ",
    "External mount error" : "Villa við tengingu í fjartengdu skráakerfi",
    "external-storage" : "ytri-gagnageymsla",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Gat ekki fengið lista yfir tengipunkta Windows-netdrifa, Svar frá þjóni var tómt",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Sumir uppsettir tengipunktar eru ekki tengdir í skráakerfið. Smelltu á rauðu örina/örvarnar til að fá frekari upplýsingar",
    "Please enter the credentials for the {mount} mount" : "Settu inn auðkenni fyrir {mount} tengipunktinn",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "Credentials saved" : "Auðkenni vistuð",
    "Credentials saving failed" : "Vistun auðkenna tókst ekki",
    "Credentials required" : "Auðkenna krafist",
    "Storage with ID \"%d\" not found" : "Geymsla með auðkennið '%d' fannst ekki",
    "Invalid backend or authentication mechanism class" : "Ógildur flokkur bakenda eða auðkenningartækni",
    "Invalid mount point" : "Ógildur tengipunktur",
    "Objectstore forbidden" : "Hlutageymsla (objectstore) bönnuð",
    "Invalid storage backend \"%s\"" : "Ógildur geymslubakendi \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ekki leyft að nota \"%s\" bakendann",
    "Not permitted to use authentication mechanism \"%s\"" : "Ekki leyft að nota \"%s\" auðkenningartæknina",
    "Unsatisfied backend parameters" : "Óuppfyllt viðföng bakenda",
    "Unsatisfied authentication mechanism parameters" : "Óuppfyllt viðföng auðkenningartækni",
    "Insufficient data: %s" : "Ónóg gögn: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Geymslan með auðkennið '%d' er ekki breytanleg af notanda",
    "Access key" : "Aðgangslykill",
    "Secret key" : "Leynilykill",
    "Builtin" : "Innbyggt",
    "None" : "Ekkert",
    "OAuth1" : "OAuth1",
    "App key" : "Lykill forrits",
    "App secret" : "Leynilykill forrits",
    "OAuth2" : "OAuth2",
    "Client ID" : "Biðlaraauðkenni",
    "Client secret" : "Leynilykill biðlara",
    "Tenant name" : "Nafn handhafa (tenant)",
    "Identity endpoint URL" : "Endapunktur auðkennisslóðar (identity endpoint URL)",
    "Domain" : "Lén",
    "Rackspace" : "Rackspace",
    "API key" : "API-lykill",
    "Global credentials" : "Víðvær innskráningarauðkenni",
    "Log-in credentials, save in database" : "Innskráningarauðkenni, vista í gagnagrunni",
    "Username and password" : "Notandanafn og lykilorð",
    "Log-in credentials, save in session" : "Innskráningarauðkenni, vista í setu",
    "User entered, store in database" : "Innskráður notandi, geyma í gagnagrunni",
    "RSA public key" : "RSA-dreifilykill",
    "Public key" : "Dreifilykill",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Vélarheiti",
    "Port" : "Gátt",
    "Region" : "Svæði",
    "Enable SSL" : "Virkja SSL",
    "Enable Path Style" : "Virkja slóðastíl",
    "WebDAV" : "WebDAV",
    "URL" : "Slóð (URL)",
    "Remote subfolder" : "Fjartengd undirmappa",
    "Secure https://" : "Öruggt https://",
    "FTP" : "FTP",
    "Host" : "Netþjónn",
    "Secure ftps://" : "Öruggt ftps://",
    "Local" : "Staðvært",
    "Location" : "Staðsetning",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rót (root)",
    "SFTP with secret key login" : "SFTP innskráning með leynilykli",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Deila",
    "SMB / CIFS using OC login" : "SMB / CIFS með OC-innskráningu",
    "Username as share" : "Notandanafn sem sameign",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Heiti á þjónustu",
    "Request timeout (seconds)" : "Tímamörk á beiðni (sekúndur)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við cURL í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við FTP í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" er ekki uppsett. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "Name" : "Nafn",
    "Storage type" : "Tegund gagnageymslu",
    "Scope" : "Umfang",
    "Enable encryption" : "Virkja dulritun",
    "Enable previews" : "Virkja forskoðanir",
    "Enable sharing" : "Virkja deilingu",
    "Check for changes" : "Fylgjast með breytingum",
    "Never" : "Aldrei",
    "Once every direct access" : "Einu sinni við hvern beinan aðgang",
    "Folder name" : "Nafn möppu",
    "External storage" : "Ytri gagnageymsla",
    "Authentication" : "Auðkenning",
    "Configuration" : "Uppsetning",
    "Available for" : "Tiltækt fyrir",
    "Add storage" : "Bæta við gagnahirslu",
    "Advanced settings" : "Ítarlegri valkostir",
    "Delete" : "Eyða",
    "Allow users to mount external storage" : "Leyfa notendum að tengja ytri gagnageymslur í skráakerfi",
    "Allow users to mount the following external storage" : "Leyfa notendum að tengja eftirfarandi ytri gagnageymslu í skráakerfi",
    "OpenStack" : "OpenStack",
    "No external storage configured" : "Engin ytri-gagnageymsla stillt",
    "You can add external storages in the personal settings" : "Þú getur bætt við ytri gagnageymslum í einkastillingunum þínum",
    "Are you sure you want to delete this external storage" : "Ertu viss um að þú viljir eyða þessari ytri geymslu?"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/files_external/l10n/is.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Utanáliggjandi gagnageymslur",
    "Personal" : "Einka",
    "System" : "Kerfi",
    "Grant access" : "Veita aðgengi",
    "Error configuring OAuth1" : "Villa við uppsetningu OAuth1",
    "Please provide a valid app key and secret." : "Settu inn gildan forritslykil og leynilykil (secret).",
    "Error configuring OAuth2" : "Villa við uppsetningu OAuth2",
    "Generate keys" : "Útbúa lykla",
    "Error generating key pair" : "Villa við að útbúa nýtt lyklapar",
    "All users. Type to select user or group." : "Allir notendur. Skrifaðu til að velja notanda eða hóp.",
    "(group)" : "(hópur)",
    "Compatibility with Mac NFD encoding (slow)" : "Samhæfni við Mac NFD kóðun (hægvirkt)",
    "Admin defined" : "Skilgreindur kerfisstjóri",
    "Are you sure you want to delete this external storage?" : "Ertu viss um að þú viljir eyða þessari ytri geymslu?",
    "Delete storage?" : "Eyða geymslu?",
    "Saved" : "Vistað",
    "Saving..." : "Er að vista ...",
    "Save" : "Vista",
    "Empty response from the server" : "Tómt svar frá þjóni móttekið",
    "Couldn't access. Please log out and in again to activate this mount point" : "Náði ekki aðgangi. Skráðu þig út og svo aftur inn til að virkja þennan tengipunkt",
    "Couldn't get the information from the remote server: {code} {type}" : "Gat ekki lesið upplýsingar frá fjartengda þjóninum: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Gat ekki fengið lista yfir fjartengda tengipunkta: {type}",
    "There was an error with message: " : "Það kom upp villa með skilaboðunum: ",
    "External mount error" : "Villa við tengingu í fjartengdu skráakerfi",
    "external-storage" : "ytri-gagnageymsla",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Gat ekki fengið lista yfir tengipunkta Windows-netdrifa, Svar frá þjóni var tómt",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Sumir uppsettir tengipunktar eru ekki tengdir í skráakerfið. Smelltu á rauðu örina/örvarnar til að fá frekari upplýsingar",
    "Please enter the credentials for the {mount} mount" : "Settu inn auðkenni fyrir {mount} tengipunktinn",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "Credentials saved" : "Auðkenni vistuð",
    "Credentials saving failed" : "Vistun auðkenna tókst ekki",
    "Credentials required" : "Auðkenna krafist",
    "Storage with ID \"%d\" not found" : "Geymsla með auðkennið '%d' fannst ekki",
    "Invalid backend or authentication mechanism class" : "Ógildur flokkur bakenda eða auðkenningartækni",
    "Invalid mount point" : "Ógildur tengipunktur",
    "Objectstore forbidden" : "Hlutageymsla (objectstore) bönnuð",
    "Invalid storage backend \"%s\"" : "Ógildur geymslubakendi \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ekki leyft að nota \"%s\" bakendann",
    "Not permitted to use authentication mechanism \"%s\"" : "Ekki leyft að nota \"%s\" auðkenningartæknina",
    "Unsatisfied backend parameters" : "Óuppfyllt viðföng bakenda",
    "Unsatisfied authentication mechanism parameters" : "Óuppfyllt viðföng auðkenningartækni",
    "Insufficient data: %s" : "Ónóg gögn: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Geymslan með auðkennið '%d' er ekki breytanleg af notanda",
    "Access key" : "Aðgangslykill",
    "Secret key" : "Leynilykill",
    "Builtin" : "Innbyggt",
    "None" : "Ekkert",
    "OAuth1" : "OAuth1",
    "App key" : "Lykill forrits",
    "App secret" : "Leynilykill forrits",
    "OAuth2" : "OAuth2",
    "Client ID" : "Biðlaraauðkenni",
    "Client secret" : "Leynilykill biðlara",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Nafn handhafa (tenant)",
    "Identity endpoint URL" : "Endapunktur auðkennisslóðar (identity endpoint URL)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Lén",
    "Rackspace" : "Rackspace",
    "API key" : "API-lykill",
    "Global credentials" : "Víðvær innskráningarauðkenni",
    "Log-in credentials, save in database" : "Innskráningarauðkenni, vista í gagnagrunni",
    "Username and password" : "Notandanafn og lykilorð",
    "Log-in credentials, save in session" : "Innskráningarauðkenni, vista í setu",
    "User entered, store in database" : "Innskráður notandi, geyma í gagnagrunni",
    "RSA public key" : "RSA-dreifilykill",
    "Public key" : "Dreifilykill",
    "RSA private key" : "RSA-einkalykill",
    "Private key" : "Einkalykill",
    "Kerberos ticket" : "Kerberos aðgöngumerki",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Vélarheiti",
    "Port" : "Gátt",
    "Region" : "Svæði",
    "Enable SSL" : "Virkja SSL",
    "Enable Path Style" : "Virkja slóðastíl",
    "Legacy (v2) authentication" : "Eldri (v2) auðkenning",
    "WebDAV" : "WebDAV",
    "URL" : "Slóð (URL)",
    "Remote subfolder" : "Fjartengd undirmappa",
    "Secure https://" : "Öruggt https://",
    "FTP" : "FTP",
    "Host" : "Netþjónn",
    "Secure ftps://" : "Öruggt ftps://",
    "Local" : "Staðvært",
    "Location" : "Staðsetning",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rót (root)",
    "SFTP with secret key login" : "SFTP innskráning með leynilykli",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Deila",
    "SMB / CIFS using OC login" : "SMB / CIFS með OC-innskráningu",
    "Username as share" : "Notandanafn sem sameign",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Heiti á þjónustu",
    "Request timeout (seconds)" : "Tímamörk á beiðni (sekúndur)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við cURL í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við FTP í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" er ekki uppsett. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "External storage support" : "Stuðningur við utanaðkomandi gagnageymslur",
    "No external storage configured or you don't have the permission to configure them" : "Engin utanaðkomandi gagnageymsla er uppsett eða að þú hefur ekki heimild til að stilla slíkt",
    "Name" : "Nafn",
    "Storage type" : "Tegund gagnageymslu",
    "Scope" : "Umfang",
    "Enable encryption" : "Virkja dulritun",
    "Enable previews" : "Virkja forskoðanir",
    "Enable sharing" : "Virkja deilingu",
    "Check for changes" : "Fylgjast með breytingum",
    "Never" : "Aldrei",
    "Once every direct access" : "Einu sinni við hvern beinan aðgang",
    "Read only" : "Skrifvarið",
    "Folder name" : "Nafn möppu",
    "External storage" : "Ytri gagnageymsla",
    "Authentication" : "Auðkenning",
    "Configuration" : "Uppsetning",
    "Available for" : "Tiltækt fyrir",
    "Click to recheck the configuration" : "Smelltu til að yfirfara aftur uppsetninguna",
    "Add storage" : "Bæta við gagnahirslu",
    "Advanced settings" : "Ítarlegri valkostir",
    "Allow users to mount external storage" : "Leyfa notendum að tengja ytri gagnageymslur í skráakerfi",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Mistókst að ná í beiðniteikn (request token). Gakktu úr skugga um að forritslykill og leynilykill séu réttir.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Mistókst að ná í aðgangsteikn (access token). Gakktu úr skugga um að forritslykill og leynilykill séu réttir.",
    "Step 1 failed. Exception: %s" : "Skref 1 mistókst. Undantekning: %s",
    "Step 2 failed. Exception: %s" : "Skref 2 mistókst. Undantekning: %s",
    "Dropbox App Configuration" : "Uppsetning Dropbox forrits",
    "Google Drive App Configuration" : "Uppsetning Google Drive forrits",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "No external storage configured" : "Engin ytri-gagnageymsla stillt",
    "You can add external storages in the personal settings" : "Þú getur bætt við ytri gagnageymslum í einkastillingunum þínum",
    "Delete" : "Eyða",
    "Allow users to mount the following external storage" : "Leyfa notendum að tengja eftirfarandi ytri gagnageymslu í skráakerfi",
    "Are you sure you want to delete this external storage" : "Ertu viss um að þú viljir eyða þessari ytri geymslu?"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
